@@ -108,7 +108,7 @@ $lang = array_merge($lang, array(
 	'MAX_AVATAR_SIZE'				=> 'En yüksek avatar boyutları',
 	'MAX_AVATAR_SIZE_EXPLAIN'		=> 'Piksel cinsinden Genişlik x Yükseklik.',
 	'MAX_FILESIZE'					=> 'En yüksek avatar dosyası büyüklüğü',
-	'MAX_FILESIZE_EXPLAIN'			=> 'Yüklenen avatar dosyaları için.',
+	'MAX_FILESIZE_EXPLAIN'			=> 'Yüklenen avatar dosyaları için. Eğer bu değer 0 olursa, gönderilebilir dosya boyutu sadece PHP ayarlarınız tarafından sınırlanır.',
 	'MIN_AVATAR_SIZE'				=> 'En düşük avatar boyutları',
 	'MIN_AVATAR_SIZE_EXPLAIN'		=> 'Piksel cinsinden Genişlik x Yükseklik.',
 ));
@@ -356,8 +356,8 @@ $lang = array_merge($lang, array(
 	'LOAD_CPF_VIEWTOPIC'			=> 'Başlık sayfalarında özel profil alanları göster',
 	'LOAD_USER_ACTIVITY'			=> 'Kullanıcıların faaliyetlerini göster',
 	'LOAD_USER_ACTIVITY_EXPLAIN'	=> 'Kullanıcı profillerinde ve kullanıcı kontrol panelinde aktif olunan başlık/forum bilgilerini göster. Bir milyon mesajdan fazla olan mesaj panolarında bu özelliği kapatmanız önerilir.',
-	'RECOMPILE_STYLES'			=> 'Bozulmuş stil bileşenlerini yeniden derle.',
-	'RECOMPILE_STYLES_EXPLAIN' => 'Dosya sisteminde bulunan stil bileşenlerini güncellemeler için kontrol et ve yeniden derle.',
+	'RECOMPILE_STYLES'			=> 'Bozulmuş stil bileşenlerini yeniden derle',
+	'RECOMPILE_STYLES_EXPLAIN' => 'Dosya sisteminde bulunan stil bileşenlerinin güncelliğini kontrol eder ve duruma göre yeniden derler',
 	'YES_ANON_READ_MARKING'			=> 'Misafirler için başlık işaretlenmesini aç',
 	'YES_ANON_READ_MARKING_EXPLAIN'   => 'Misafirler için başlıkların ya da mesajların okunmuş/okunmamış durum bilgileri saklanacaktır. Eğer bu özellik kapalıysa, misafirler için mesajlar her zaman okunmuş olarak işaretlenecektir.',
 	'YES_BIRTHDAYS'					=> 'Doğum günü listelemeyi aç',
