@@ -191,7 +191,7 @@ $lang = array_merge($lang, array(
 	'FORM_INVALID'         => 'Gönderilen form geçersiz. Tekrar göndermeyi deneyin.',
 	'FORUM'					=> 'Forum',
 	'FORUMS'				=> 'Forumlar',
-	'FORUMS_MARKED'			=> 'Seçilen forumlar okunmuş sayıldı.',
+	'FORUMS_MARKED'			=> 'Forumlar okunmuş sayıldı.',
 	'FORUM_CAT'				=> 'Forum kategorisi',
 	'FORUM_INDEX'			=> 'Forum ana sayfa',
 	'FORUM_LINK'			=> 'Forum bağlantısı',
@@ -437,7 +437,7 @@ $lang = array_merge($lang, array(
 	'POSTS'				=> 'Mesajlar',
 	'POSTS_UNAPPROVED'	=> 'Bu başlıktaki en az bir mesaj onaylanmadı.',
 	'POST_BY_AUTHOR'	=> 'gönderen',
-	'POST_BY_FOE'		=> 'Bu mesaj <strong>%1$s</strong> tarafından gönderildi, kişi şu an sizin ignore listenizde. Bu mesajı görüntülemek için %2$sBURAYA%3$s tıklayın.',
+	'POST_BY_FOE'		=> 'Bu mesaj <strong>%1$s</strong> tarafından gönderildi ve bu kullanıcı şu an sizin engellenenler listenizde. Mesajı görüntülemek için %2$sBURAYA%3$s tıklayın.',
 	'POST_DAY'			=> 'Ortalama her gün %.2f mesaj',
 	'POST_DETAILS'		=> 'Mesaj detayları',
 	'POST_NEW_TOPIC'	=> 'Yeni başlık gönder',
@@ -450,6 +450,7 @@ $lang = array_merge($lang, array(
 	'POST_TIME'			=> 'Mesaj tarihi',
 	'POST_TOPIC'			=> 'Yeni bir başlık gönder',
 	'POST_UNAPPROVED'	=> 'Bu mesaj onay için bekliyor',
+	'POWERED_BY'			=> 'Powered by %s',
 	'PREVIEW'			=> 'Önizleme',
 	'PREVIOUS'            => 'Önceki',      // Used in pagination
 	'PREVIOUS_STEP'         => 'Önceki',
@@ -458,6 +459,7 @@ $lang = array_merge($lang, array(
 	'PRIVATE_MESSAGES'	=> 'Özel mesajlar',
 	'PRIVATE_MESSAGING'	=> 'Özel mesajlaşma',
 	'PROFILE'			=> 'Kullanıcı Kontrol Paneli',
+	'RANK'						=> 'Rütbe',
 
 	'READING_FORUM'				=> '%s içerisindeki başlıklar görüntüleniyor',
 	'READING_GLOBAL_ANNOUNCE'	=> 'Global duyuru okunuyor',
