@@ -136,7 +136,8 @@ $lang = array_merge($lang, array(
 	'CREATE_FOLDER'				=> 'Klasör ekle…',
 	'CURRENT_IMAGE'				=> 'Şu anki resim',
 	'CURRENT_PASSWORD'			=> 'Şu anki şifre',
-	'CURRENT_PASSWORD_EXPLAIN'	=> 'Eğer şifrenizi, e-posta adresinizi ya da kullanıcı adınızı değiştirmek istiyorsanız şu anki şifrenizi doğrulamalısınız.',
+	'CURRENT_PASSWORD_EXPLAIN'	=> 'Eğer e-posta adresinizi ya da kullanıcı adınızı değiştirmek istiyorsanız, şu anki şifrenizi girmelisiniz.',
+	'CURRENT_CHANGE_PASSWORD_EXPLAIN' => 'Şifrenizi, e-posta adresinizi, ya da kullanıcı adınızı değiştirmek için şu anki şifrenizi girmelisiniz.',
 	'CUR_PASSWORD_EMPTY'		=> 'Şu anki şifrenizi girmediniz.',
 	'CUR_PASSWORD_ERROR'		=> 'Girilen şu anki şifre hatalı.',
 	'CUSTOM_DATEFORMAT'			=> 'Özel…',
@@ -386,6 +387,7 @@ $lang = array_merge($lang, array(
 	'RULE_ADDED'				=> 'Kural başarıyla eklendi.',
 	'RULE_ALREADY_DEFINED'		=> 'Bu kural önceden zaten belirlendi.',
 	'RULE_DELETED'				=> 'Kural başarıyla silindi.',
+	'RULE_LIMIT_REACHED'				=> 'Daha fazla ÖM kuralı ekleyemezsiniz. Kuralların en yüksek sayısına ulaştınız.',
 	'RULE_NOT_DEFINED'			=> 'Kural doğru şekilde belirlenmedi.',
 	'RULE_REMOVED_MESSAGE'				=> 'Özel mesaj süzgecine göre zamanı gelen bir özel mesaj silindi.',
 	'RULE_REMOVED_MESSAGES'				=> 'Özel mesaj süzgecine göre zamanı gelen %d özel mesaj silindi.',
@@ -413,12 +415,12 @@ $lang = array_merge($lang, array(
 
 	'UCP'						=> 'Kullanıcı Kontrol Paneli',
 	'UCP_ACTIVATE'				=> 'Hesabı aktifleştir',
-	'UCP_ADMIN_ACTIVATE'		=> 'Not: Hesabınız aktif edilmeden önce doğru bir e-posta adresi girmelisiniz. Yöneticiler hesabınızı inceleyecekler ve eğer onaylarlarsa belirttiğiniz adresten bir e-posta alacaksınız.',
+	'UCP_ADMIN_ACTIVATE'		=> 'Not: Hesabınız aktif edebilmek için doğru bir e-posta adresi girmelisiniz. Yöneticiler hesabınızı inceleyecekler ve eğer onaylarlarsa belirttiğiniz adrese bir e-posta alacaksınız.',
 	'UCP_AIM'					=> 'AOL Instant Messenger',
 	'UCP_ATTACHMENTS'			=> 'Eklentiler',
 	'UCP_COPPA_BEFORE'			=> '%s tarihinden önce',
 	'UCP_COPPA_ON_AFTER'		=> '%s tarihinde veya daha sonra',
-	'UCP_EMAIL_ACTIVATE'		=> 'Not: Hesabınız aktif edilmeden önce doğru bir e-posta adresi girmelisiniz. Belirttiğiniz adresten bir e-posta alacaksınız ve içeriğinde bir aktivasyon bağlantısı bulunacaktır.',
+	'UCP_EMAIL_ACTIVATE'		=> 'Not: Hesabınızı aktif edebilmek için doğru bir e-posta adresi girmelisiniz. Belirttiğiniz adrese bir e-posta alacaksınız ve içeriğinde bir aktivasyon bağlantısı bulunacaktır.',
 	'UCP_ICQ'					=> 'ICQ numarası',
 	'UCP_JABBER'				=> 'Jabber adresi',
 
